// Copyright Earl Warren <contact@earl-warren.org>
// Copyright Loïc Dachary <loic@dachary.org>
// SPDX-License-Identifier: MIT

package f3

import (
	"time"
)

type ReviewComment struct {
	Common
	InReplyTo *Reference `json:"in_reply_to"`
	Content   string     `json:"content"`
	TreePath  string     `json:"tree_path"`
	DiffHunk  string     `json:"diff_hunk"`
	Position  int        `json:"position"`
	Line      int        `json:"line"`
	CommitID  string     `json:"commit_id"`
	PosterID  *Reference `json:"poster_id"`
	CreatedAt time.Time  `json:"created_at"`
	UpdatedAt time.Time  `json:"updated_at"`
}

func (o ReviewComment) GetCmpIgnoreFields() []string {
	return append(o.Common.GetCmpIgnoreFields(), ".CreatedAt", ".UpdatedAt", ".DiffHunk")
}

func (o *ReviewComment) GetReferences() References {
	references := o.Common.GetReferences()
	return append(references, o.PosterID)
}

func (o *ReviewComment) Clone() Interface {
	clone := &ReviewComment{}
	*clone = *o
	return clone
}
